
# Copyright (C) 2010-2023 RhodeCode GmbH
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License, version 3
# (only), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# This program is dual-licensed. If you wish to learn more about the
# RhodeCode Enterprise Edition, including its added features, Support services,
# and proprietary license terms, please see https://rhodecode.com/licenses/

import pytest

from rhodecode.lib.html_filters import sanitize_html


@pytest.mark.parametrize(
    "src_html, expected_html",
    [
        ('<div>ITEM</div>', '<div>ITEM</div>'),
        ('<div>ITEM</div> <!-- comment here -->', '<div>ITEM</div> <!-- comment here -->'),
        ('<div style="not-allowed:true">ITEM</div>', '<div style="">ITEM</div>'),
        ('<div onload="ACTION">ITEM</div>', '<div>ITEM</div>'),
        ('<a onload="ACTION" style="color:red">ITEM</a>', '<a style="color:red;">ITEM</a>'),
        ('<img src="/file.png"></img>', '<img src="/file.png">'),
        ('<img src="/file.png"></img>', '<img src="/file.png">'),
    ])
def test_html_sanitizer_options(src_html, expected_html):
    parsed_html = sanitize_html(src_html)
    assert parsed_html == expected_html
